| download_map_data | R Documentation |
The urls are listed in https://code.highcharts.com/mapdata/.
download_map_data(
url = "custom/world.js",
showinfo = FALSE,
quiet = FALSE,
method = "curl"
)
url |
The map's url. |
showinfo |
Show the properties of the downloaded map to know how
are the keys to add data in |
quiet |
Boolean parameter to turn off download messages (on by default). |
method |
A string value for the download method used by
|
hcmap
## Not run:
mpdta <- download_map_data("https://code.highcharts.com/mapdata/countries/us/us-ca-all.js")
mpdta <- download_map_data("https://code.highcharts.com/mapdata/countries/us/us-ca-all.js",
quiet = TRUE
)
str(mpdta, 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.