get_data_from_map: Helper function to get the data inside the map data The urls...

View source: R/highmaps.R

get_data_from_mapR Documentation

Helper function to get the data inside the map data The urls are listed in https://code.highcharts.com/mapdata/.

Description

Helper function to get the data inside the map data The urls are listed in https://code.highcharts.com/mapdata/.

Usage

get_data_from_map(mapdata)

Arguments

mapdata

A list obtained from download_map_data.

See Also

download_map_data

Examples

## Not run: 
dta <- download_map_data("https://code.highcharts.com/mapdata/countries/us/us-ca-all.js")
get_data_from_map(dta)

## End(Not run)

highcharter documentation built on April 22, 2026, 5:09 p.m.