hc_add_annotation: Helper to add annotations from data frame or list

View source: R/highcharts-api-add.R

hc_add_annotationR Documentation

Helper to add annotations from data frame or list

Description

Helper to add annotations from data frame or list

Usage

hc_add_annotation(hc, ...)

hc_add_annotations(hc, x)

Arguments

hc

A highchart htmlwidget object.

...

Arguments defined in https://api.highcharts.com/highcharts/annotations.

x

A list or a data.frame of annotations.

Details

The x elements must have xValue and yValue elements


highcharter documentation built on April 22, 2026, 5:09 p.m.