Learn R Programming

highcharter (version 0.2.0)

hc_scrollbar: Adding scrollbar options to highstock objects

Description

Options regarding the scrollbar which is a means of panning over the X axis of a chart.

Usage

hc_scrollbar(hc, ...)

Arguments

hc
A highchart htmlwidget object.
...
Arguments defined in http://api.highcharts.com/highstock#scrollbar.