hcpxy_update_point: Update options series in a higchartProxy object

View source: R/proxy.R

hcpxy_update_pointR Documentation

Update options series in a higchartProxy object

Description

Update options series in a higchartProxy object

Usage

hcpxy_update_point(proxy, id = NULL, id_point = NULL, ...)

Arguments

proxy

A higchartProxy object.

id

A character indicating the id of the series' point to update.

id_point

A vector value indicating the point's index to update, (0 based).

...

Arguments defined in https://api.highcharts.com/class-reference/Highcharts.Point. The arguments will be the same for each series. So if you want update data it is used this function sequentially for each point


highcharter documentation built on April 22, 2026, 5:09 p.m.