hcpxy_update_series: Update options series in a higchartProxy object

View source: R/proxy.R

hcpxy_update_seriesR Documentation

Update options series in a higchartProxy object

Description

Update options series in a higchartProxy object

Usage

hcpxy_update_series(proxy, id = NULL, ...)

Arguments

proxy

A higchartProxy object.

id

A character vector indicating the id (or ids) of the series to update.

...

Arguments defined in https://api.highcharts.com/highcharts/plotOptions.series. The arguments will be the same for each series. So if you want update data it is used this function sequentially for each series.


highcharter documentation built on April 22, 2026, 5:09 p.m.