highchartProxy: Send commands to a Highcharts instance in a Shiny app

View source: R/proxy.R

highchartProxyR Documentation

Send commands to a Highcharts instance in a Shiny app

Description

Send commands to a Highcharts instance in a Shiny app

Usage

highchartProxy(shinyId, session = shiny::getDefaultReactiveDomain())

Arguments

shinyId

Single-element character vector indicating the output ID of the chart to modify

session

The Shiny session object to which the map belongs; usually the default value will suffice.


highcharter documentation built on April 22, 2026, 5:09 p.m.