is.hexcolor: Check if a string vector is in hexadecimal color format

View source: R/helpers.R

is.hexcolorR Documentation

Check if a string vector is in hexadecimal color format

Description

Check if a string vector is in hexadecimal color format

Usage

is.hexcolor(x)

Arguments

x

A string vectors

Examples


x <- c("#f0f0f0", "#FFf", "#99990000", "#00FFFFFF")

is.hexcolor(x)

highcharter documentation built on April 22, 2026, 5:09 p.m.