hex_to_rgba: Transform colors from hexadecimal format to rgba hc notation

View source: R/helpers.R

hex_to_rgbaR Documentation

Transform colors from hexadecimal format to rgba hc notation

Description

Transform colors from hexadecimal format to rgba hc notation

Usage

hex_to_rgba(x, alpha = 1)

Arguments

x

colors in hexadecimal format

alpha

alpha

Examples


hex_to_rgba(x <- c("#440154", "#21908C", "#FDE725"))

highcharter documentation built on April 22, 2026, 5:09 p.m.